/// <reference types="node" />
/** BIP32 hierarchical deterministic node */
export interface HDNode {
    readonly publicKey: Buffer;
    readonly privateKey: Buffer | null;
    readonly chainCode: Buffer;
    readonly address: string;
    derive(index: number): HDNode;
}
export declare namespace HDNode {
    /** create node from mnemonic words */
    function fromMnemonic(words: string[], path?: string): HDNode;
    /**
     * create node from xpub
     * @param pub public key
     * @param chainCode chain code
     */
    function fromPublicKey(pub: Buffer, chainCode: Buffer): HDNode;
    /**
     * create node from xpriv
     * @param priv private key
     * @param chainCode chain code
     */
    function fromPrivateKey(priv: Buffer, chainCode: Buffer): HDNode;
}
